==> org-lsst-ccs-command-1.2-sources.jar: org/lsst/ccs/command/Dictionary.java <==
package org.lsst.ccs.command;

/**
 * A command dictionary contains all the information needed to provide
 * help and perform tab completion. It does not by itself provide sufficient
 * functionality to invoke a command, for this a CommandSet which is a combination of a 
 * command dictionary and a command invoker is required. A CommandDictionary is a collection of
 * CommandDefinitions, plus a few convenience methods.
 * @author tonyj
 */
public interface Dictionary extends Iterable<DictionaryCommand> {

    /**
     * Test if a given command is present in a dictionary.
     * @param command The command (or alias) to search for
     * @return <code>true</code>If the command is found
     */
    public boolean containsCommand(BasicCommand command);
    
    /**
     * Find a given command in the dictionary
     * @param command The command (or alias) to search for
     * @return The index of the command in the dictionary, or <code>-1</code> if 
     * the command is not found.
     */
    public int findCommand(BasicCommand command);

    /**
     * Test if a given command is present in a dictionary
     * @param command The command (or alias) to search for
     * @param argumentCount The number of arguments associated with the command
     * @return <code>true</code>If the command is found
     */
    public boolean containsCommand(String command, int argumentCount);
    
    /**
     * Find a given command in the dictionary.
     * @param command The command (or alias) to search for
     * @param argumentCount The number of arguments associated with the command
     * @return The index of the command in the dictionary, or <code>-1</code> if 
     * the command is not found.
     */
    public int findCommand(String command, int argumentCount);

    
    /**
     * The size of the dictionary.
     * @return The number of commands in this dictionary.
     */
    public int size();

    /**
     * Get the command at the given index.
     * @param index
     * @return The command found
     * @throws IndexOutOfBoundsException If the index is out of bounds.
     */
    public DictionaryCommand get(int index) throws IndexOutOfBoundsException;
    
}

==> org-lsst-ccs-command-1.4.3-sources.jar: org/lsst/ccs/command/Dictionary.java <==
package org.lsst.ccs.command;

import java.io.Serializable;

/**
 * A command dictionary contains all the information needed to provide
 * help and perform tab completion. It does not by itself provide sufficient
 * functionality to invoke a command, for this a CommandSet which is a combination of a 
 * command dictionary and a command invoker is required. A CommandDictionary is a collection of
 * CommandDefinitions, plus a few convenience methods.
 * @author tonyj
 */
public interface Dictionary extends Iterable<DictionaryCommand>, Serializable {

    /**
     * Test if a given command is present in a dictionary.
     * @param command The command (or alias) to search for
     * @return <code>true</code>If the command is found
     */
    public boolean containsCommand(BasicCommand command);
    
    /**
     * Find a given command in the dictionary
     * @param command The command (or alias) to search for
     * @return The DictionaryCommand, or <code>null</code> if 
     * the command is not found.
     */
    public DictionaryCommand findCommand(BasicCommand command);

    /**
     * Test if a given command is present in a dictionary
     * @param command The command (or alias) to search for
     * @param argumentCount The number of arguments associated with the command
     * @return <code>true</code>If the command is found
     */
    public boolean containsCommand(String command, int argumentCount);
    
    /**
     * Find a given command in the dictionary.
     * @param command The command (or alias) to search for
     * @param argumentCount The number of arguments associated with the command
     * @return The DictionaryCommand, or <code>null</code> if 
     * the command is not found.
     */
    public DictionaryCommand findCommand(String command, int argumentCount);

    /**
     * The size of the dictionary.
     * @return The number of commands in this dictionary.
     */
    public int size();  
}
